// rev1: Bot can view from 45 to 135 degrees and measure distance (11704 bytes)
// rev2: Measurements are now printed on the lcd-screen (14692 bytes)
// rev3: Bot can decide which direction is furthest (14936 bytes)
// rev4: Added 2 continuous rotating servo's to move around (15316 bytes)

// Issues:
// - Bot won't return if all the value's are less then 10cm

#include <Servo.h>
#include "Ultrasonic.h"
#include <Wire.h> 
#include <LiquidCrystal_I2C.h>

Ultrasonic ultrasonic(12,13); //(trig,echo)
LiquidCrystal_I2C lcd(0x27,20,4);
Servo panservo;
Servo leftservo;
Servo rightservo;

byte degs[] = { 45, 90, 135 };
int distance[ 3 ] = { 0 };

void setup() {
  Serial.begin(9600);
  panservo.attach(6);
  leftservo.attach(5);
  rightservo.attach(3);
  lcd.init();
  lcd.backlight();
  lcd.print("Starting up...");
  
  // Be sure the continous servo's don't move
  leftservo.write(90);
  rightservo.write(90);
}

void loop()
{  
  // Rotate pan-servo and measure distance on 45, 90 and 135 degrees.
  for( int i = 0; i < 3; i++ )
  {
    panservo.write(degs[i]);
    delay(300);
    distance[i] = ultrasonic.Ranging(CM);
    if (distance[i] > 1000)
    {
      distance[i] = 300;
    }      
  }
  
  // Print the measurements to the lcd screen
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print(distance[0]);
  lcd.print(" cm on 45 deg.");
  lcd.setCursor(0,1);
  lcd.print(distance[1]);
  lcd.print(" cm on 90 deg.");
  lcd.setCursor(0,2);
  lcd.print(distance[2]);
  lcd.print(" cm on 135 deg.");
  
  // Decide which distance is the furthest.
  if (distance[0] <= distance[1] && distance[1] >= distance[2]) // 90 degrees is greatest
  {
    lcd.setCursor(0,3);
    lcd.print("Direction: Forward");
    leftservo.write(180);
    rightservo.write(0);
  }
  else if (distance[0] > distance[1] && distance[1] >= distance[2]) // 45 degrees is greatest
  {
    lcd.setCursor(0,3);
    lcd.print("Direction: Left");
    leftservo.write(0);
    rightservo.write(0);
  }
  else if (distance[0] <= distance[1] && distance[1] < distance[2]) // 135 degrees is greatest
  {
    lcd.setCursor(0,3);
    lcd.print("Direction: Right");
    leftservo.write(180);
    rightservo.write(180);
  }
  else if (distance[0] < 10 && distance[1] < 10 && distance[1] < 10) // All object are closer then 10cm.
  {
      lcd.setCursor(0,3);
      lcd.print("Direction: Return");
      leftservo.write(0);
      rightservo.write(180);
  }
  delay(10000);
}
